===
API
===

This part of the documentation lists the full API reference of all public
classes and functions.

clophfit.binding module
++++++++++++++++++++++++

.. automodule:: clophfit.binding
   :undoc-members:

clophfit.prtecan
++++++++++++++++

.. automodule:: clophfit.prtecan
   :show-inheritance: Titration
   :special-members: __almost_eq__

   .. include:: ./prtecan.uml.rst

..
   .. autoclass:: Titration
      :show-inheritance: True

..
   .. autoclass:: Tecanfile
	  :exclude-members: path
